Class: Aws::PrivateNetworks::Types::CommitmentConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrivateNetworks::Types::CommitmentConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-privatenetworks/types.rb
Overview
Determines the duration and renewal status of the commitment period for a radio unit.
For pricing, see Amazon Web Services Private 5G Pricing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automatic_renewal ⇒ Boolean
Determines whether the commitment period for a radio unit is set to automatically renew for an additional 1 year after your current commitment period expires.
-
#commitment_length ⇒ String
The duration of the commitment period for the radio unit.
Instance Attribute Details
#automatic_renewal ⇒ Boolean
Determines whether the commitment period for a radio unit is set to automatically renew for an additional 1 year after your current commitment period expires.
Set to True, if you want your commitment period to automatically
renew. Set to False if you do not want your commitment to
automatically renew.
You can do the following:
-
Set a 1-year commitment to automatically renew for an additional 1 year. The hourly rate for the additional year will continue to be the same as your existing 1-year rate.
-
Set a 3-year commitment to automatically renew for an additional 1 year. The hourly rate for the additional year will continue to be the same as your existing 3-year rate.
-
Turn off a previously-enabled automatic renewal on a 1-year or 3-year commitment.
You cannot use the automatic-renewal option for a 60-day commitment.
260 261 262 263 264 265 |
# File 'lib/aws-sdk-privatenetworks/types.rb', line 260 class CommitmentConfiguration < Struct.new( :automatic_renewal, :commitment_length) SENSITIVE = [] include Aws::Structure end |
#commitment_length ⇒ String
The duration of the commitment period for the radio unit. You can choose a 60-day, 1-year, or 3-year period.
260 261 262 263 264 265 |
# File 'lib/aws-sdk-privatenetworks/types.rb', line 260 class CommitmentConfiguration < Struct.new( :automatic_renewal, :commitment_length) SENSITIVE = [] include Aws::Structure end |